==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/enums/UpdateSummariesPropertiesState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Overall update state of the stamp.
 */
public enum class UpdateSummariesPropertiesState(
    public val javaValue: com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState> {
    Unknown(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.Unknown),
    AppliedSuccessfully(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.AppliedSuccessfully),
    UpdateAvailable(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.UpdateAvailable),
    UpdateInProgress(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.UpdateInProgress),
    UpdateFailed(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.UpdateFailed),
    NeedsAttention(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.NeedsAttention),
    PreparationInProgress(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.PreparationInProgress),
    PreparationFailed(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.PreparationFailed),
    ;

    override fun toJava(): com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState):
            UpdateSummariesPropertiesState =
            UpdateSummariesPropertiesState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/enums/UpdateSummariesPropertiesState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Overall update state of the stamp.
 */
public enum class UpdateSummariesPropertiesState(
    public val javaValue: com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState> {
    Unknown(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.Unknown),
    AppliedSuccessfully(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.AppliedSuccessfully),
    UpdateAvailable(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.UpdateAvailable),
    UpdateInProgress(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.UpdateInProgress),
    UpdateFailed(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.UpdateFailed),
    NeedsAttention(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.NeedsAttention),
    PreparationInProgress(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.PreparationInProgress),
    PreparationFailed(com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState.PreparationFailed),
    ;

    override fun toJava(): com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.azurestackhci.enums.UpdateSummariesPropertiesState): UpdateSummariesPropertiesState =
            UpdateSummariesPropertiesState.values().first { it.javaValue == javaType }
    }
}
